package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````!14``#0```!0@0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````A&X`
M`(1N```%```````!``$```#`?0``P'T!`,!]`0!\`@``K!(```8```````$`
M`@```,A]``#(?0$`R'T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3`?0``P'T!`,!]`0!``@``0`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$\````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3P```%````!4````
M60```%H```!A````8@```&,`````````90```&8`````````9P```&@```!K
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````8!`````````#``<```````"``0```````P`1``P`````
M`````````!(```#:`0`````````````2````%```````````````$0`````"
M`````````````!$```!\`0`````````````2````&P``````````````$@``
M`+D!`````````````!(````C```````````````2````*@``````````````
M$@````T"`````````````!(```#%`0`````````````2````,P``````````
M````(````$X#`````````````"$```!+```````````````2````40``````
M````````$@```%@``````````````!(````;`P`````````````2````#`,`
M````````````$@```)("`````````````!(```!?```````````````2````
M,P(`````````````$@```&8``````````````!(```#'`@`````````````2
M````;0``````````````$@```'4``````````````!(```"P`@``````````
M```2````?0``````````````$@```(,``````````````!(```",````````
M```````@````!0,`````````````$@```*@``````````````!(```"M````
M```````````2````'@(`````````````$0```,X"`````````````!(```!@
M`@`````````````2````M```````````````$@```%("`````````````!(`
M``!R`P`````````````2````V0(`````````````$0```$T#````````````
M`!$```"$`@`````````````2````.@,`````````````$@```$\#````````
M`````!$```"[```````````````2````,@,`````````````$@```,0`````
M`````````!$```"*`0`````````````2````U@``````````````(@```.4`
M`````````````"````#[```````````````2````_0(`````````````$@``
M`'`"`````````````!(``````0`````````````2````!@$`````````````
M(````+L"`````````````!(````@`0`````````````2````J@$`````````
M````$@```"4!`````````````!(```"@`@`````````````2````F0$`````
M````````$@```"L!`````````````!(````\`0`````````````2````+@(`
M````````````$@```'X``````````````!(````_`@`````````````2````
M>0(`````````````$@```"L#`````````````!(```!"`0`````````````2
M````(P,`````````````$@```%8!`````````````!(````I`@``````````
M```2````Z`$`````````````$@```%T!`````````````!(```!D`0``````
M```````2````3`,`````````````(0```'4!`````````````!(```!R!```
M;)`!```````0`!(`1P,``'$3``"4`0``$@`)`/H!```Q,0```@```!(`"@"T
M`P``K1\``*@$```2``D`@@0``*DF```X````$@`)`)$#``!9&P``!````!(`
M"0`F!```81````(````2``<`UP,``%4D``!4`@``$@`)`"P$```\@`$`````
M`!``$@!:!```71L``&0!```2``D`#P0``#R``0``````$``2`*(#``!!'P``
M;````!(`"0#!`P```1H``$`````2``D`R0,``/$>``!`````$@`)`.T#``"U
M+P``P@```!(`"0`"!```P1P``!(````2``D`&P0``&R0`0``````$``2`'T$
M``!LD`$``````!``$@!7`P``(14``$`````2``D`.@0``-,<``":````$@`)
M`/@#```X@`$`!````!$`$0!3!```/(`!```````0`!$`%`0```45````````
M$@`)`",$``!Y+P``/````!(`"0!@`P``,1\``!`````2``D`>P,``(D:``#0
M````$@`)`&<$``!W,```N````!(`"0!Q!```;)`!```````0`!(`1@0``&T=
M``"$`0``$@`)``!L:6)P97)L+G-O`&]P96YD:7(`<W1D97)R`')E86QL;V,`
M86-C97-S`'-N<')I;G1F`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K
M`&=E='!I9`!S=')C;7``;65M<V5T`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``
M;'-T870`8VQO<V5D:7(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P
M96X`<W1R<W1R`'-T<F-H<@!R96%D;&EN:P!?7W-T86-K7V-H:U]G=6%R9`!?
M7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C;&]S
M90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E<G)N
M;U]L;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC`&UE;6-P>0!S
M=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T
M`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V
M7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F,N;75S;"UA
M<FUV-RYS;RXQ`&9P<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`')E861D
M:7(`<W!R:6YT9@!S=')T;VL`<W1R;F-P>0!?7VQI8F-?<W1A<G1?;6%I;@!?
M7U]E;G9I<F]N`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S
M971U<%]L:6)P871H`'!A<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE
M86X`6%-?26YT97)N86QS7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L
M`'!A<E]B87-E;F%M90!?7V)S<U]S=&%R=`!?7V5N9%]?`'-H85]I;FET`%]?
M8G-S7W-T87)T7U\`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P
M87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L
M96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4`P'T!`!<```#$
M?0$`%P```+Q_`0`7````R'\!`!<```#4?P$`%P````"``0`7````"(`!`!<`
M```,@`$`%P```!2``0`7````&(`!`!<````<@`$`%P```""``0`7````)(`!
M`!<````L@`$`%P```#"``0`7````.(`!`!<```#`?P$`%04``,1_`0`5!@``
MS'\!`!4.``#0?P$`%1\``-A_`0`5(P``W'\!`!4I``#@?P$`%2T``.1_`0`5
M,```Z'\!`!4R``#L?P$`%3,``/!_`0`5.```]'\!`!4]``#X?P$`%3X``/Q_
M`0`50P``Q'X!`!8#``#(?@$`%@0``,Q^`0`6!P``T'X!`!8(``#4?@$`%@D`
M`-A^`0`6"@``W'X!`!8+``#@?@$`%@P``.1^`0`6#0``Z'X!`!8.``#L?@$`
M%A```/!^`0`6$0``]'X!`!82``#X?@$`%A,``/Q^`0`6%````'\!`!85```$
M?P$`%A8```A_`0`6%P``#'\!`!88```0?P$`%AD``!1_`0`6&@``&'\!`!8;
M```<?P$`%AP``"!_`0`6'0``)'\!`!8>```H?P$`%B```"Q_`0`6(0``,'\!
M`!8B```T?P$`%B0``#A_`0`6)0``/'\!`!8F``!`?P$`%B<``$1_`0`6*```
M2'\!`!8K``!,?P$`%BP``%!_`0`6+@``5'\!`!8O``!8?P$`%C$``%Q_`0`6
M,@``8'\!`!8S``!D?P$`%C0``&A_`0`6-0``;'\!`!8V``!P?P$`%C<``'1_
M`0`6.0``>'\!`!8Z``!\?P$`%CL``(!_`0`6/```A'\!`!8_``"(?P$`%D``
M`(Q_`0`600``D'\!`!9"``"4?P$`%D0``)A_`0`610``G'\!`!9&``"@?P$`
M%D<``*1_`0`62```J'\!`!9)``"L?P$`%DH``+!_`0`62P``M'\!`!9,``"X
M?P$`%DX```&UO>@!0'!'!.`MY03@G^4.X(_@"/"^Y4!N`0``QH_B%LJ,XD#^
MO.4`QH_B%LJ,XCC^O.4`QH_B%LJ,XC#^O.4`QH_B%LJ,XBC^O.4`QH_B%LJ,
MXB#^O.4`QH_B%LJ,XAC^O.4`QH_B%LJ,XA#^O.4`QH_B%LJ,X@C^O.4`QH_B
M%LJ,X@#^O.4`QH_B%LJ,XOC]O.4`QH_B%LJ,XO#]O.4`QH_B%LJ,XNC]O.4`
MQH_B%LJ,XN#]O.4`QH_B%LJ,XMC]O.4`QH_B%LJ,XM#]O.4`QH_B%LJ,XLC]
MO.4`QH_B%LJ,XL#]O.4`QH_B%LJ,XKC]O.4`QH_B%LJ,XK#]O.4`QH_B%LJ,
MXJC]O.4`QH_B%LJ,XJ#]O.4`QH_B%LJ,XIC]O.4`QH_B%LJ,XI#]O.4`QH_B
M%LJ,XHC]O.4`QH_B%LJ,XH#]O.5X1_WG`,:/XA;*C.)T_;SE`,:/XA;*C.)L
M_;SE`,:/XA;*C.)D_;SE`,:/XA;*C.)<_;SE`,:/XA;*C.)4_;SE`,:/XA;*
MC.),_;SE`,:/XA;*C.)$_;SE`,:/XA;*C.(\_;SE`,:/XA;*C.(T_;SE`,:/
MXA;*C.(L_;SE`,:/XA;*C.(D_;SE`,:/XA;*C.(<_;SE`,:/XA;*C.(4_;SE
M`,:/XA;*C.(,_;SE`,:/XA;*C.($_;SE`,:/XA;*C.+\_+SE`,:/XA;*C.+T
M_+SE`,:/XA;*C.+L_+SE`,:/XA;*C.+D_+SE`,:/XA;*C.+<_+SE`,:/XA;*
MC.+4_+SE`,:/XA;*C.+,_+SE`,:/XA;*C.+$_+SE`,:/XA;*C.*\_+SE`,:/
MXA;*C.*T_+SE>$?]YP#&C^(6RHSBJ/R\Y0#&C^(6RHSBH/R\Y7A'_><`QH_B
M%LJ,XI3\O.4`QH_B%LJ,XHS\O.4`QH_B%LJ,XH3\O.4`QH_B%LJ,XGS\O.4`
MQH_B%LJ,XG3\O.4`QH_B%LJ,XFS\O.4`QH_B%LJ,XF3\O.4`QH_B%LJ,XES\
MO.4`QH_B%LJ,XE3\O.4`QH_B%LJ,XDS\O.5PM8BPS>D&$`62!JD%J@>H34S_
M]USO34M\1.-8`Y-,2P.:XU@11AA&!)/_]\3N24OC6!YX2$OE6'ZY__<2[T=*
M>D0081"Y`2#_]U+O__=T[RAH__>F[X#X/6<H:/_WH.^0^)XS0_`"`X#XGC,H
M:/_WF.^0^)XS0_`!`X#XGC,'F`4PL/&`3P?3-4LV2.-8>$091@.3__=J[H``
M__="[P%&!IPQ2R)H>T0"8#!*F&!Z1$)@+TIZ1!)H@F`N2GI$0?@,+P0B6F`!
M(P>:FD(VW``A`O&`0P,S*$U`^",0`)$G27U$`T8#,BAI>43_]Y3N!$88N2AI
M__<([P1&(4U]1"AI__?,[A](>$0`\"3Y8+GK:".Y'4AX1`#P'?GH8!M+>T38
M:`BQ`?`(^1E+>T08:?_W2N__]_CM($8(L'"]5/@C4`$S0?@$7\#G+&L!`$0!
M``!``0``#`$``"`!``"D;`$`)`$``*,=```^;`$`RQ\``!!L`0#`'P``!&P!
M`.4%``#H:P$`?1T``"0=``#&:P$`NFL!`$_P``M/\``.`TEY1&A&(/`/#.5&
M`/`"^+9H`0`?M0M+"TI[1)I8`I(*2II8`Y(`(@&2"4J;6`(=`),!:`*;`YC_
M]VCN!;!=^`3[`+^.:0$`'`$```0!```0`0``"$@)2PE*>$1[1(-">D2"L`70
M!TO36`&3"[$"L!A'`K!P1P"_TFH!`-!J`0!(:0$`&`$```I("TEX1'E$"QK9
M#PE*`>NC`4D0>D2"L`70!TO36`&3"[$"L!A'`K!P1P"_H&H!`)YJ`0`,:0$`
M.`$```Y+$+5[1`Y,&WA\1*.Y#4OC6".Q#$M[1!AH__<N[O_WM_\*2^-8&[$)
M2'A$__=T[0$B"$M[1!IP$+T`OV1J`0#::`$`,`$``!9J`0`4`0``@E@``#1J
M`0`(M0=+!TI[1)M8*[$&20=(>41X1/_W"NZ]Z`A`IN<`OX9H`0`T`0``!&H!
M`$)8```82RWI\$=[1(I&!48XLQ9*FU@<:`2S`T8>1A/X`1LYN:%&=AO(1EGX
M!'LGN3Q&$^`]*?70\.<R1BE&.$;_]W#M`"COT;M=/2OLT:CK!`2D$,KX`$!T
M'#Q$($:]Z/"'!$;ZYP"_5F@!`"@!```'M0Q*#$MZ1--8:48;:`&33_```__W
MOO\(2@=+>D336!IH`9M:0`'0__<T[@.P7?@$^P"_ZF<!`"P!``#49P$`<[44
M2A1+>D336`1&&V@!DT_P``-N1A%-?40Q1B!&__>9_TBY#DH,2WI$TU@::`&;
M6D`-T/_W#NX*2P":ZU@;:`/K@@-::$/X!"L`*OK1Y.<"L'"]JF<!`"P!``"8
M9P$`B&<!`"@!```MZ?!/#49)2DE+>D336(6P&V@#DT_P``,+>`9&/2L(OP$U
M*$;_]]SM`JD'1C!&__==_]_X`)$$1OE$J+'_]]#MN$)$TP$\%?@!.P3X`3\`
M*_G1`"`X2C9+>D336!IH`YM:0&#0__?"[31+6?@#H-KX`+!;^"0PB[DQ2P3Q
M`@A[1!IH3^J("%JQ04981O_W4NS*^```H+E/\/\PV^<!-.CG`2)`1AI@__>F
M[`&0`"CRT%E&J/$(`O_WI.P!F\KX`##:^``PF$0`(TCX!#P"E#-&&$83^`$K
M"K$]*OG1%TL"-UGX`T"`&SA$W?@(D-3X`(#_]X#L2/@I```HS-`C:`*:4_@B
M(!;X`1L31A%P`3()L3TI]]$](AIP%?@!*P/X`2\`*OG1E><%L+WH\(\^9P$`
M+`$``!!G`0#P9@$`*`$``&IH`0`MZ?!',DHS2WI$TUB<L!MH&Y-/\``#!4;`
ML0-XL['_]];K!D:0L2Q/W_BP@-_XL)!_1/A$^40P1O_W%NP$1GBY,$;_]U3L
M*$;_]]SL)4HA2WI$TU@::!N;6D`UT/_W).T3-#E&($;_]_KK`"CCT$%&($;_
M]_3K`"C=T"A&__<.[8)&($;_]PKM4$0",/_W$.R"1B-&*D9)1O_WZ.QI1E!&
M__?*[`$P4$8+T`2;`_1P0[/U@$\%T?_WH_]01O_WMNRYY__W\.OXYQRPO>CP
MAP"__&4!`"P!``!_&```?!@``'T8``"T90$`$+462A9+>D2<L--8:48$1AMH
M&Y-/\``#__?NZ\BY!)L#]'!#L_6`3P+0L_4@3P;1`B$@1O_W=.NP^H#P0`D)
M2@=+>D336!IH&YM:0`/0__>X[``@\^<<L!"]`+\690$`+`$``-ID`0`3M0I,
M"DM\1.-8&&C_]X#L"$L)2>-8>40!DPA+`9I[1`*PO>@00/_W9;P`OZYD`0`@
M`0``/`$``%$7```R5```$[4,2PQ*>T2<6"!H__=@[/_WUO\@:/_W7.P`(@=+
M"$E[1,WI`#('2GE$>D3_]S#K`K`0O6YD`0`@`0``B!D``!L7``#G"0``,+4N
M22Y*K?4`78>P>42*6`WU`%,4,Q)H&F!/\``"__<LZRA*`ZQZ1`"2)TH#1D'R
M`0$@1GI$__<"ZT,<#=$`(R)('TEX1`WU`%)!6!0R"&@1:$A`+=#_]SSLL/6`
M7P#9_]X-]8!5$#4@1D_T@%(I1O_WE.L$'N+;8!S_]R[K`T8`*-S0J$("T@(9
ME4+HTZM"`MDJ&9-"X]-!\@$"E$+?W")&&$8I1O_W_.L`(@-&`E7&YQA&#?4`
M70>P,+T@9`$`+`$``/86``#<%@``Z&,!`/_WEK\MZ?!/#$9+2:WU@UU*2GE$
MA[`%1DE(BE@-]8-3>$04,Q)H&F!/\``"__>>_2\A!D8H1O_W+.N(L4%(*49X
M1/_WY_U`23Q*>40-]8-3BE@4,Q%H&FA10&;0__?0ZRA&__?(ZSE)!T9Y1"!&
M__>>ZP1&W_C8@-_XV)#?^-B@^$3Y1/I$`"S8T"-X`"L(OT1&5K$A1C!&__>,
MZBBY+TEY1/_WA.L$1NWG($;_]Z+K(Q@`(!H;$_@!'2\I%-!['!-$L_6`7[G:
M#?%T"R-&2D9/](!16$;-Z0"E__=(Z@$PL/6`7P+9_]X8<./G`JPA1EA&__=.
MZZ"Y(VD#]'!#L_4`3P[1`2%81O_W*NI(N11(649X1/_W?OU81O_WG.H%1I'G
M$$D`('E$N^<H1@WU@UT'L+WH\(\`OTIC`0`L`0``,!8``!D6```28P$`_!4`
M`(<5``"R%@``Y!4``,85``!'%0``0!4```-&$_@!*P*Y<$<O*@B_&$;WYQ"U
M!$8(L0-X*[D?2'A$O>@00/_W8+K_]S#K`3@@1(1"`T8>TAIX`3@O*OC0&7@:
M1B\I`_'_,Q+1$T8!.YQ"&D8#TA%X`3LO*?C0$AN3'+/U@%\8V`$RLO6`7PW9
M_]Z<0N33G$+IT2-X+RL"T0A(>$3-YP=(>$3*YP=+(49[1!A&__=NZA"]`"#\
MYX$4```?%```>A0``!IC`0`PM49*1DMZ1(NPTUAJ1D5)&V@)DT_P``-Y1`'Q
M"@,!\2H$%488:%EH"#,#Q:-"*D;WT1N(/$@K@'A$__>M_#M(.TQX1/_WJ/PZ
M2'Q$>$3_]Z/\.4AX1/_WG_PX2'A$__>;_#=(>$3_]Y?\-DAX1/_WD_PU2'A$
M__>/_"!&__>,_#)(>$3_]XC\,4AX1/_WA/PP2'A$__=@_`%&$+$@1O_WK_PM
M2'A$__=7_`%&&+$K2'A$__>E_"I(>$3_]TW\`4:8L2A(>$3_]YO\)TDG2'E$
M>$3_]Y7\)DH12WI$TU@::`F;6D`8T/_W@NHB2'A$__<S_`%&$+$@2'A$Y.<?
M20HB>40-\1$`__>"Z0`HW=$<2`WQ&P%X1-;G"[`PO4)A`0`L`0``S%```!X4
M```=%```4Q0``!L4```<%```&Q0``",4``#0$P``'Q0``"44``"[$P``'Q0`
M`!X4```=$P``'!0``'@3```R%```IQ,``&Y@`0#X$P``FQ,``/43``!_$P``
M"+4+2WM$&V@!,PS1"4AX1/_WX/L@L0!X$+$P.!B_`2`%2WM$&&`%2WM$&&@(
MO0"_#&$!``$3``#N8`$`Z&`!``BU__<8ZO_W9.D`L0!H"+WWM19/!$9_1#A&
M__>[^R%&!48(L0-X*[D12'A$`["]Z/!``^3_]R[IL+D@1O_W[ND&1BA&__?J
MZ3!$`C#_]_#H!D8(2PA)(D9Y1`"5>T3_]\;I,48X1N'G`[#PO2@3```4$P``
M,A(```03```MZ?!/K?4`3;^P/JVE\5P*5$;?^!`4W_@0)'E$W_@,Y(I8#?4`
M0_Y$$FC#^/0@3_```O0S#O$0#`[Q!`.E\70&@$:3Z`<`AN@'`+SH#P`/Q)SH
M`P`.\2@.I?%H"83H`P">Z`<`B>@'`/%(\D]X1/_W4_M_1`1&J+$#>)NQ__>*
M_R!&__>^Z`1&ZTGG2GE$#?4`0XI8]#,1:!IH44``\+R!__>$Z?_W;O\$1BBY
M6?@$"P`H8='A3'Q$($;_]W+I0``!,/_W>.B!1H-&W4D!/'E$%/@!+P`J6=%:
M^`1+A+$@1O_W&OL$1@`H]M`#>``K\]#_]WS\`"COT"!&__>"Z`1&LD8TN5KX
M!&L`+E'0,W@`*T31($;_]T3I@T9(1O_W0.E81`#R!$M81O_W1.@&1L5+Q4E[
M1`"3Q4LB1GM$>43-^`20__<6Z4_TX'$P1O_WZ.@!,"_1__?>Z`-H$2LJT+Q*
MO$FX6`"3V/@`(#-&`&AY1/_WIN@`)(?G__?.^@`HE=`#>``KDM#_]SSHC>=8
M1@61"_$""__W[.@%F9GG,$;_]R7\`"BNT#!&__<JZ`1&J.<T1J[GI?'@!"%&
M,$;_]Q+H@D90L:)+I$GX6-CX`"`S1GE$`&C_]W3HS.<C:0/T<$.S]8!/[M'4
M^!B0__?FZ(%%Z-$C:</S"`.S]>!_XM%81O[WV.\$1I5(>$3_]X7Z`"A`\(&`
MV/@`<#A&__?"Z`,H@48AV8Y)!#AY1#A$_O>8[]"YN?$$#P30N409^`4\+RL2
MT=CX!("X\0`/#=!`1O_WJ.@#*`C9@TD$.'E$0$3^]X#O`"@(OT=&__=L_H%&
M`"A`\)V``48X1O[WR.^`1@`H`/"5@$_P`@I/\/\S;_`1`LWX`*`O'_[W6.\&
M(CE&0$;_]R;H%?@$/``K0=%[>$,K/M&[>$$K.]'[>$,K.-$[>4@K-=%[>44K
M,M%/\/\S;_`Y`D!&S?@`H/[W-N\I(CE&0$;_]P;H,D9?2V!)>T3-Z0!S7TMY
M1'M$($;_]SKH,$;_]Q;H6T@A1GA$__=9^B!&__=`_KCFV/@`</[W<N\!1CA&
M__=%_`=&`"A_]'6O<><`(P`B`)-`1@`C_O<&[P#P1?Z"1D_T`$(Y1D!&_O?0
M[P(>)]Q`1J7Q1`?^][[O,#U11CA&`/"Q_JA&W_@,H?I$*$911A?X`2L)\0$)
M_O?X[[GQ%`\%\0(%\M$`(XCX*#`Z2SM)>T3-Z0"#.DLR1GM$>42IYSE&4$8`
M\"[^RN<V239(>41X1/_W`_K^]\SN-$LT27M$S>D``S-+,D8@1GM$>43^]\[O
M,4TQ3]_XR(!]1']$^$1/].!Q($;^]YKO`3"%T?[WD.\#:!$K@-'^]ZKN"O$!
M"@"0*T8R1CE&($;-Z0&H_O>N[^7G($8-]0!-/["]Z/"/[EX!`"P!```N8`$`
MD!$``)9>`0!\7@$`'!(```L2``"U$0``HA$``-H0```(`0``?A$``%<1``#%
M$```4A$``"41``!0$0``D!```!X/``#T#@``:P\``*@0``#D#P``=@X```X/
M``"?#@``>A```,,/``!&#@``-@X``,$/``!:$```+>GX3X!+@4I[1)Q8(&C^
M]U;O!48@:/[W4N^5^&0P@/AE,'M(>$3_]R/Y(+$#>#$K`=%#>`NQ__=O_"!H
M_O<^[W1)"R,!(GE$_O>>[CB[(&C^]S3O<$D#(P$B>43^]Y3N!48`*&31(&C^
M]RCO:TD#(P$B>43^]XCN!48`*'W0:$AX1/_W]?@&1@`H9]`@:/[W%N\R1NMH
M&6C^]X+N;>`!)<-HW_B`D9]IW_A\H?E$V?@$,"!HJT(%\?\X"-W^]_[N`"-"
M1CE&_O<*[@9&0+E72WM$6F@!.I!%N=$!)AU&(N#9^`@P`FA3^"6PDV@*Z@,#
ML_6`;P?1T6A81O[WWNT`*.71`373YR!H_O?8[C%H`B,`(O[W[.X!1N[G_O?0
M[CE&_O>([0$V:V@@:+-"]=R.YR!H_O?$[NMH/4H9:'I$_O<P[NMH&VB;:%L"
MC-4@:/[WMN[K:!EH_O?.[83G__=J^@9&(&B6L_[WJN[K:#)&&6C^]Q;N,$;^
M]XCN(&C^]Y[N!48@:/[WFNXJ20$B>43^]V3M*4H!1GI$*$;^]P+N(&C^]XSN
M`".`^&4P)$@D3'A$__=>^'Q$X&"`N:!H__?,_.!@6+D?2'A$_O=>[?[W=NX=
M2WM$FFCK:!)H7.<;3$_TX'%\1.!H_O=([A$H"M!#'`$K!]D#1J%H%4CB:`EH
M>$3^]T+MO>CXCUA:`0`@`0``:PT``,0.``"U#@``I`X``-T,``!46P$```0@
M`#!;`0#5#0``C`T``)<-``"F"P``3%H!`&T-```N6@$`'EH!`%8-```XM01&
M__<1^__W!OL%1O_W&_QPL6RQ(WA;L09)*$9Y1/[W?.V%0@31($:]Z#A`__?K
MN#B]S0L``"WI\$_\2OU+>D33L--8`:H41AMH49-/\``#`/%<!0#Q'`-3^`0;
M";J=0D3X!!OXT4`D$48-:DMK!#)K0(UH"6AK0$M`3^KS<P$\TV/QT>A*T.D`
MC`&9!&D11-#X".`A1,1HQ6B.Z@0*"NH,"HKJ!`H"G`'K^&$41%%$+$1/ZK@*
M`YV.ZKP+BNJ\!@OJ"`L.0!5$B^H."Z-$=40$G(;JO`8+Z_%K+D2*ZK$%!NO[
M9@6?!>H+!11$3^J["XOJL0F%Z@H%!.N\!"5$">H&"0:<%T0%Z_9E5T2)ZK$)
MB^JV"A1$N40*Z@4*">OU:03KL0%/ZK4%!YR*Z@L*BD2%ZK8!`>H)`11$7$0(
MGX'JM@$*Z_EJA>JY"R%$`>OZ80F<"^H*"Q=$3^JZ"@?KM@>*ZKD&%$0.0(OJ
M!0N&ZKD&)42[1"Y$"IT+Z_%KBNJQ!!5$!.H+!`;K^V8%Z[D)3^J["PN=A.H*
M!$Q$B^JQ"0GJ!@D51%5$B>JQ":E$#)T$Z_9DB^JV"A5$#9\*Z@0*">OT:07K
ML0%/ZK0$BNH+"@Z=BD071(3JM@$*Z_EJ7T0!Z@D!A.JY"X'JM@$+Z@H+%40%
MZ[8%.42+Z@0+`>OZ8:M$3^JZ"@^=BNJY!A5$#D`L1(;JN08F1!"<"^OQ:XKJ
ML0<41`?J"P<&Z_MF!.NY"4_JNPL1G(?J"@=/1(OJL0D)Z@8)%$141(GJL0FA
M1!*<!^OV9XOJM@H41!.="NH'"@3KL0&*Z@L*">OW:12<3^JW!XI$%40*Z_EJ
MA^JV`5U$A^JY"Q1$`>H)`0OJ"@N!ZK8!B^H'"P3KM@8I1+-$8TT5G@'K^F$N
M1$_JN@H6G#=$BNJY!DY`+$0+Z_%K%YHW1`3KN0D8GHKJL02$Z@L$!^O[9RI$
M3^J["Z%$+D0)Z_=IDD0&Z[$&B^JQ`HOJMP&!Z@D!>D`.1!F9DD0*Z_EJ*41/
MZKD)&IJ+1(GJMP$;G('J"@$J1`;K^F:+1`+KMP>)ZKH""^OV:W)`+$1/ZK8&
M')FA1(;JN@2$Z@L$%T0I1!V:!^O[9Z%$`>NZ`8;JNPH)Z_=IBNH'"BI$3^JW
M!QZ<%D2'ZKL"@NH)`BQ$44061!^:`>OY803KNPN'ZKD$!NOQ9DQ`*D1/ZK$!
MHT0Z1""<@>JY!W=`+$0Z1"&?"^OV:P3KN0F!ZK8$`NO[8H3J"P0'ZP4*3^J[
M"XI$B^JV`5%`BD0BF:%$*40)Z_)I(YPDGP'KM@:+ZK(!@>H)`0KK^6HL1$_J
MN0D.1"]$!NOZ9J-$!^NR!XGJL@2)ZKH"<D"$Z@H$%T0EFJ-$"^OV:RI$3^JV
M!B:<D42&ZKH"@NH+`B>9+$0'Z_MGD40'X)EY@EJAZ]ENS%<!`"P!```$Z[H$
MANJ["@GK]VF*Z@<**41/ZK<'*)H.1(?JNP&!Z@D!*D141`3K^60.1`+KNPN'
MZKD"!NOT9F)`3^JT!$3JN0H$ZKD%"NH&"NM)2NH%"BF=DT0-1`OK]FL]1$3J
MM@<$ZK8"!^H+!Q=#*IJJ1`KK^VH*1$_JNPL"Z[D"2^JV"1=$">H*"0OJM@))
MZ@()*YH'Z_IG"D1+ZKH%%$0]0`OJN@(50RR:H40*1`GK]VD"Z[8&3^JW!S5$
M1^JZ!@?JN@0&Z@D&)D,MG`7K^64,1%Q$1^JY"P?JN0(+Z@4+2^H""RZ:)D0*
M1`;K]68"Z[H*3^JU!=-$1>JY"@7JN0(*Z@8*2NH""B^:"^OV:PI$.D1%ZK8'
M!>JV!`?J"P<G0S"<DD0*Z_MJ#$1/ZKL+!.NY!$OJM@D+ZK8"">H*"4GJ`@DQ
MFB=$"D0'Z_IG%41+ZKH""^JZ!#I`(D,RG*E$#$0)Z_=I!.NV!D_JMP<R1$?J
MN@8'ZKH%!NH)!BY#,YT"Z_EB#41=1$?JN0L'ZKD$"^H""TOJ!`LTG"Y$#$0&
MZ_)F!.NZ"D_JL@+31$+JN0H"ZKD$"NH&"DKJ!`HUG`OK]FL,1#Q$0NJV!:)$
M!>H+!0+JM@0E0S:<"NO[:@Q$3^J["P3KN0E-1$OJM@D+ZK8'">H*"4GJ!PDW
MGP7K^F4/1$OJN@071"Q`"^JZ`A1#.)JY1`I$">OU:0+KM@9/ZK4%-$1%ZKH&
M!>JZ`@;J"0860SF:!.OY9`I$6D061$7JN0(%ZKD'(D`Z0SJ?!NOT9@]$3^JT
M!`?KN@=$ZKD*.D0*Z@8*!.JY!TKJ!PH[GP+K]F(/1#U$1.JV!U5$!^H""@3J
MM@=*Z@<*/)\%Z_)E.40!Z[D)T40]GT_JL@H^F5E*">OU:1=$$40\1(KJM@<!
MZ[8&BNJU`8'J"0%O0`Y$/YD\1`3K^6011$_JN0F*1(GJM0%A0(I$0)E!GQ%$
M!NOT9@'KM06)ZK0!"NOV:G%`%T1/ZK8&N42&ZK0'A^H*![E$0I\-1!=$0YD%
MZ_IE!^NT!(;JN@<)Z_5I;T`11$_JM04.1(7JN@&!Z@D!#D1$F3Q$$40$Z_ED
M`>NZ"H7JN0%A0(I$19D&Z_1F$41/ZK0$#41&GX3JN0%Q0!=$#41'F0KK]FH'
MZ[D)A.JV!P7K^F6'Z@H'$41/ZKH*#$2*ZK8!:4`,1$B9N4011`GK]6D!Z[8&
MBNJU`8'J"0$.1$F9!.OY9!%$3^JY"8I$2I^)ZK4!84`71(I$2YD&Z_1F!^NU
M!8GJM`<*Z_9J$41W0$_JM@:)1(;JM`&!Z@H!B41,F3U$$40%Z_IE`>NT!(;J
MN@%I0`Q$39D)Z_5I$41/ZK4%!.``O]R\&X_6P6+*#D2%ZKH!@>H)`0Y$3ID$
MZ_ED$40!Z[H*A>JY`0&K84"*1-/X.!'3^#PQ!NOT9A%$3^JT!!-$#41#1(3J
MN0$*Z_9J<4`#Z[D)A.JV`PU$@^H*`P7K^F5+1`/K]6,#8`[KN@.#8,-H"DH#
MZ[8&`VEE1!Q$"$MZ1$5@QF`$8=-8&FA1FUI``=#^]_CI4["]Z/"/8$\!`"P!
M```(M6`@_O?PZ`I*"TD"8`+QB#)"8`+Q*4*B]982HO:+8H)@HO&(,L)@`"+`
MZ002@F'"90B]`2-%9_#ATL,MZ?!!%D8%1D-IT@";&"B_@FE#822_`3*"88-I
M!?$<!P/K5G.#8<!M\+'`\4`$M$(X1*B_-$:(0@/2`QF90@#2_]Z(0@'K!`@!
MV4!%^-,B1O[WD.GK;2-$0"OK91?1*$;_]V3[048V&P7Q7`@_+A#<N4("V;L9
MF4+BT[E"`M*+&9]"W=,R1CA&_O=TZ>YEO>CP@;E"`=E!1=+3N4(!\4`#`=*?
M0LS3#$8Z1E3X!!N<0D+X!!OYT2A&__<X^T`^(4;4YRWI\$$!\1P'2VF.:0Q&
M@"&3^H/XP_/%`UH<."H%1C:Z^50'ZP(`0]T`(<+Q0`+^]TKH($;_]QG[."(`
M(3A&_O="Z"!&Q.D5:/_W#_OC>"!&*W!CB&MP(V@;"JMP(VCK<.-Y*W'CB&MQ
M8V@;"JMQ8VCK<>-Z*W)CB6MRHV@;"JMRHVCK<N-[*W/CB6MSXV@;"JMSXVCK
M<^-\*W1CBFMT(VD;"JMT(VGK=+WH\$'^]]FX`"'"\3@"PN<`OP&UO>@!0'!'
M+W1M<`!005)?5$U01$E2`%1%35!$25(`5$U0`%5315(`55-%4DY!344`+BX`
M)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ
M4$%2.CI"3T]4`"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`!005)?4%)/1TY!
M344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])
M3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!
M4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,
M1%],24)205)97U!!5$@`4UE35$5-`"4P,G@`)7,E<R5S)7,`<&%R+0`E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E
M<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)3
M24].`#$N,#0Y`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H`+64`+2T`979A;"`G97AE8R`O=7-R+V)I;B]P
M97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD
M97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)
M0RP@)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O
M<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U
M=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ
M1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK
M('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?
M=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL
M93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G
M+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@
M=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII
M9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@
M,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M
M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@
M/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S
M92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O
M=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL
M96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@
M:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["B1005)?34%'24,@
M/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?
M<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE
M("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@
M)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\
M3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?
M<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P
M<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S
M:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R
M-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2![
M"B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C
M:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@
M96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H
M:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:RA?1D@L("1M86=I8U]P;W,L
M(#`I.PIR96%D*%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!
M4E]-04=)0RDI.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'
M24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC
M7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P
M.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F
M+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D
M8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI
M<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&
M24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q
M*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H
M("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD
M968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I
M/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD
M("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M
M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*
M96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D
M("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H
M(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F
M:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE
M?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB
M=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I]
M.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*
M;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U
M;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@9&5L971E("1R97%U:7)E7VQI
M<W1[)&UO9'5L97T@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D
M97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E
M9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN
M97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H
M("1I;F9O+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]
M"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1I;F9O+3Y[8W)C
M?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE
M;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO
M9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@
M*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI
M('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"
M4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U
M:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D
M9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@
M)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@
M97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@
M/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI
M;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%2
M1U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E
M('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H
M:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T
M;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R
M(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H
M)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q
M("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@
M>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G
M9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A
M(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD[
M"FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\
M)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM
M;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E
M860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z
M:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI
M('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO
M+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C
M86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG
M+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B
M)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP
M,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE
M.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O
M<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P
M;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@
M)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)
M37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H
M<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X
M=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M
M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E
M="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S
M>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H
M)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E
M<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN
M8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)3
M1%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG
M.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I
M;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L
M('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML
M:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL
M97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN
M8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@
M>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ
M6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S
M=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*
M:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H
M+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@
M)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N
M9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@
M86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B
M+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE
M*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&
M24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B
M.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,
M13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T
M<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD
M9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC
M;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT
M96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II
M<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII
M9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;
M.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96XH;7D@
M)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H
M)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E
M<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*
M)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@
M=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR
M97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI[
M"G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD
M;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@
M)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%2
M7U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6
M>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U
M=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*
M)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO
M9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]
M"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@
M(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M
M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@
M70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]
M"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&
M:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E
M<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U
M;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS
M=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN
M84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q
M=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L
M.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA
M;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI
M8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$[
M"G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2
M.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T
M97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS
M,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E
M<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E
M(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E
M<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER
M92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2![
M"B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H
M"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2
M(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@
M=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T
M:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@
M9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97
M:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I
M;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]
M("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@
M?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<
M5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R
M+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G
M;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F
M+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@
M,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE
M;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L
M("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2`O+R`D;71I
M;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD9&EG97-T
M(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q
M.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*
M;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA
M;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I
M('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H
M+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M
M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO
M<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO
M9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T
M96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G
M;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.
M5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*
M?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN
M9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N
M86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345]
M(&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2![
M"FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF
M("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2![
M"B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E
M86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D
M14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N
M9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG
M>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*
M?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6
M>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D
M*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I
M(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R
M;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W
M9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)
M5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!
M4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#
M3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLG
M4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'
M("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R
M7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*
M:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM
M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,
M14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY0
M05)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U
M:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS
M92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@
M0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z
M.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI
M.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@
M<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B
M.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O
M9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?
M7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?
M15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/
M4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,`7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````I%@``T14```$````!`````0```.@"```/````
MC@0```P```!A$```#0```#$Q```9````P'T!`!L````$````&@```,1]`0`<
M````!````/7^_V\L`0``!0```-0(```&````%`(```H```"L!```"P```!``
M```5``````````,```"X?@$``@```/`!```4````$0```!<```!P#@``$0``
M`(`-```2````\````!,````(````&`````````#[__]O`0``"/K__V\0````
M`````````````````````````````````````````````````````,A]`0``
M`````````&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0
M``!H$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```:!``
M`&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```
M:!```&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0``!H
M$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0
M``!H$```:!```&@0``!H$```:!```&@0``!H$```<1,`````````````,3$`
M````````````81``````````````````````````````````````````````
M````````````@`$`_____S@Q``!C,0```````#TQ```],@``2#$``$\R``!0
M,0```````%0Q``!9,0```````/,S``!'0T,Z("A!;'!I;F4@."XS+C`I(#@N
M,RXP`$=#0SH@*$%L<&EN92`Y+C(N,"D@.2XR+C``03(```!A96%B:0`!*```
M``4W+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1H"'`$>!"(!`"YS:'-T<G1A
M8@`N:6YT97)P`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;"YD>6X`
M+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;64`
M+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N
M8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````````````````
M````````````````````````````````"P````$````"````%`$``!0!```8
M```````````````!`````````!,```#V__]O`@```"P!```L`0``Z`````,`
M````````!`````0````=````"P````(````4`@``%`(``,`&```$`````P``
M``0````0````)0````,````"````U`@``-0(``"L!``````````````!````
M`````"T````)`````@```(`-``"`#0``\`````,`````````!`````@````V
M````"0```$(```!P#@``<`X``/`!```#````$`````0````(````/P````$`
M```&````8!```&`0```(```````````````"`````````#H````!````!@``
M`&@0``!H$```"`,`````````````!`````0```!%`````0````8```!P$P``
M<!,``,`=``````````````0`````````2P````$````&````,#$``#`Q```(
M```````````````"`````````%$````!`````@```#@Q```X,0``2#T`````
M`````````0````````!9`````0````(```"`;@``@&X```0`````````````
M``0`````````8P````X````#````P'T!`,!]```$```````````````$````
M!````&\````/`````P```,1]`0#$?0``!```````````````!`````0```![
M````!@````,```#(?0$`R'T``/`````$``````````0````(````A`````$`
M```#````N'X!`+A^``!(`0`````````````$````!````(D````!`````P``
M``"``0``@```/```````````````!`````````"/````"`````,````\@`$`
M/(```#`0``````````````0`````````E`````$````P`````````#R````T
M```````````````!`````0```)T````#``!P``````````!P@```,P``````
M`````````0`````````!`````P``````````````HX```*T`````````````
)``$`````````
